==> haskell-cpphs-1.20.9.1-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cpphs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 cpphs
version:              1.20.9.1
visibility:           public
id:                   cpphs-1.20.9.1-KMTErBmnvc26XA8bncSIwV
key:                  cpphs-1.20.9.1-KMTErBmnvc26XA8bncSIwV
license:              LicenseRef-LGPL
copyright:            2004-2017, Malcolm Wallace
maintainer:           Malcolm Wallace <Malcolm.Wallace@me.com>
author:               Malcolm Wallace <Malcolm.Wallace@me.com>
homepage:             http://projects.haskell.org/cpphs/
synopsis:
    A liberalised re-implementation of cpp, the C pre-processor.

description:
    Cpphs is a re-implementation of the C pre-processor that is both
    more compatible with Haskell, and itself written in Haskell so
    that it can be distributed with compilers.

    This version of the C pre-processor is pretty-much
    feature-complete and compatible with traditional (K&R)
    pre-processors.  Additional features include: a plain-text mode;
    an option to unlit literate code files; and an option to turn
    off macro-expansion.

category:             Development
abi:                  2774a8e886c30febdf54da5adda43906
exposed:              True
exposed-modules:
    Language.Preprocessor.Cpphs Language.Preprocessor.Unlit

hidden-modules:
    Language.Preprocessor.Cpphs.CppIfdef
    Language.Preprocessor.Cpphs.HashDefine
    Language.Preprocessor.Cpphs.MacroPass
    Language.Preprocessor.Cpphs.Options
    Language.Preprocessor.Cpphs.Position
    Language.Preprocessor.Cpphs.ReadFirst
    Language.Preprocessor.Cpphs.RunCpphs
    Language.Preprocessor.Cpphs.SymTab
    Language.Preprocessor.Cpphs.Tokenise TimeCompat

import-dirs:          /usr/lib/ghc-9.4.8/site-local/cpphs-1.20.9.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/cpphs-1.20.9.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/cpphs-1.20.9.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cpphs
hs-libraries:         HScpphs-1.20.9.1-KMTErBmnvc26XA8bncSIwV
depends:
    base-4.17.2.1 directory-1.3.7.1
    polyparse-1.13-LdwKes91BNc9xm9kzNQ4gM time-1.12.2

haddock-interfaces:   /usr/share/doc/haskell-cpphs/html/cpphs.haddock
haddock-html:         /usr/share/doc/haskell-cpphs/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cpphs-1.20.9.1-15-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cpphs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 cpphs
version:              1.20.9.1
visibility:           public
id:                   cpphs-1.20.9.1-2DOXkAxjH8X2uNUFEwCYhv
key:                  cpphs-1.20.9.1-2DOXkAxjH8X2uNUFEwCYhv
license:              LicenseRef-LGPL
copyright:            2004-2017, Malcolm Wallace
maintainer:           Malcolm Wallace <Malcolm.Wallace@me.com>
author:               Malcolm Wallace <Malcolm.Wallace@me.com>
homepage:             http://projects.haskell.org/cpphs/
synopsis:
    A liberalised re-implementation of cpp, the C pre-processor.

description:
    Cpphs is a re-implementation of the C pre-processor that is both
    more compatible with Haskell, and itself written in Haskell so
    that it can be distributed with compilers.

    This version of the C pre-processor is pretty-much
    feature-complete and compatible with traditional (K&R)
    pre-processors.  Additional features include: a plain-text mode;
    an option to unlit literate code files; and an option to turn
    off macro-expansion.

category:             Development
abi:                  1c7d0f4c3992460b05f9fc0ce2e38fdd
exposed:              True
exposed-modules:
    Language.Preprocessor.Cpphs Language.Preprocessor.Unlit

hidden-modules:
    Language.Preprocessor.Cpphs.CppIfdef
    Language.Preprocessor.Cpphs.HashDefine
    Language.Preprocessor.Cpphs.MacroPass
    Language.Preprocessor.Cpphs.Options
    Language.Preprocessor.Cpphs.Position
    Language.Preprocessor.Cpphs.ReadFirst
    Language.Preprocessor.Cpphs.RunCpphs
    Language.Preprocessor.Cpphs.SymTab
    Language.Preprocessor.Cpphs.Tokenise TimeCompat

import-dirs:          /usr/lib/ghc-9.4.8/site-local/cpphs-1.20.9.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/cpphs-1.20.9.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/cpphs-1.20.9.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cpphs
hs-libraries:         HScpphs-1.20.9.1-2DOXkAxjH8X2uNUFEwCYhv
depends:
    base-4.17.2.1 directory-1.3.7.1
    polyparse-1.13.1-Kzbu3d62mnu6HLgy0ka478 time-1.12.2

haddock-interfaces:   /usr/share/doc/haskell-cpphs/html/cpphs.haddock
haddock-html:         /usr/share/doc/haskell-cpphs/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
